@@ -5,9 +5,9 @@ from pytpp.attributes.top import TopAttributes
 
 
 class AgentDiscoveryBaseAttributes(DiscoveryStatisticsAttributes, ScheduleBaseAttributes, TopAttributes, metaclass=IterableMeta):
-	__config_class__ = "Agent Discovery Base"
-	configuration = Attribute('Configuration')
-	discovery_exclusion_dn = Attribute('Discovery Exclusion DN')
-	protection_key = Attribute('Protection Key')
-	report_dn = Attribute('Report DN')
-	status = Attribute('Status')
+    __config_class__ = "{key}"
+    configuration = Attribute('Configuration')
+    discovery_exclusion_dn = Attribute('Discovery Exclusion DN')
+    protection_key = Attribute('Protection Key')
+    report_dn = Attribute('Report DN')
+    status = Attribute('Status')
