@@ -3,5 +3,5 @@ from pytpp.attributes.driver_base import DriverBaseAttributes
 
 
 class AgentModuleHandlerAttributes(DriverBaseAttributes, metaclass=IterableMeta):
-	__config_class__ = "Agent Module Handler"
-	version = Attribute('Version')
+    __config_class__ = "{key}"
+    version = Attribute('Version')
