@@ -3,4 +3,4 @@ from pytpp.attributes.organization import OrganizationAttributes
 
 
 class AgentModuleHandlerContainerAttributes(OrganizationAttributes, metaclass=IterableMeta):
-	__config_class__ = "Agent Module Handler Container"
+    __config_class__ = "{key}"
