@@ -3,4 +3,4 @@ from pytpp.attributes.top import TopAttributes
 
 
 class CAContainerAttributes(TopAttributes, metaclass=IterableMeta):
-	__config_class__ = "CA Container"
+    __config_class__ = "{key}"
