@@ -4,7 +4,7 @@ from pytpp.attributes.x509_certificate_base import X509CertificateBaseAttributes
 
 
 class ClientCertificateWorkAttributes(ClientWorkBaseAttributes, X509CertificateBaseAttributes, metaclass=IterableMeta):
-	__config_class__ = "Client Certificate Work"
-	certificate_container = Attribute('Certificate Container')
-	naming_pattern = Attribute('Naming Pattern')
-	transfer_allowed = Attribute('Transfer Allowed', min_version='18.3')
+    __config_class__ = "{key}"
+    certificate_container = Attribute('Certificate Container')
+    naming_pattern = Attribute('Naming Pattern')
+    transfer_allowed = Attribute('Transfer Allowed', min_version='18.3')
