@@ -3,4 +3,4 @@ from pytpp.attributes.client_group_base import ClientGroupBaseAttributes
 
 
 class ClientSubgroupAttributes(ClientGroupBaseAttributes, metaclass=IterableMeta):
-	__config_class__ = "Client Subgroup"
+    __config_class__ = "{key}"
