@@ -3,4 +3,4 @@ from pytpp.attributes.top import TopAttributes
 
 
 class ClientWorkContainerAttributes(TopAttributes, metaclass=IterableMeta):
-	__config_class__ = "Client Work Container"
+    __config_class__ = "{key}"
