@@ -3,4 +3,4 @@ from pytpp.attributes.top import TopAttributes
 
 
 class ClientWorkRootAttributes(TopAttributes, metaclass=IterableMeta):
-	__config_class__ = "Client Work Root"
+    __config_class__ = "{key}"
