@@ -3,5 +3,5 @@ from pytpp.attributes.top import TopAttributes
 
 
 class CodeSigningApplicationCollectionAttributes(TopAttributes, metaclass=IterableMeta):
-	__config_class__ = "Code Signing Application Collection"
-	code_signing_application_dn = Attribute('Code Signing Application DN', min_version='19.2')
+    __config_class__ = "{key}"
+    code_signing_application_dn = Attribute('Code Signing Application DN', min_version='19.2')
