@@ -3,4 +3,4 @@ from pytpp.attributes.top import TopAttributes
 
 
 class CodeSigningApplicationContainerAttributes(TopAttributes, metaclass=IterableMeta):
-	__config_class__ = "Code Signing Application Container"
+    __config_class__ = "{key}"
