@@ -3,5 +3,5 @@ from pytpp.attributes.code_signing_environment_base import CodeSigningEnvironmen
 
 
 class CodeSigningDotNetEnvironmentAttributes(CodeSigningEnvironmentBaseAttributes, metaclass=IterableMeta):
-	__config_class__ = "Code Signing DotNet Environment"
-	signing_key_dn = Attribute('Signing Key DN', min_version='20.2')
+    __config_class__ = "{key}"
+    signing_key_dn = Attribute('Signing Key DN', min_version='20.2')
