@@ -3,4 +3,4 @@ from pytpp.attributes.top import TopAttributes
 
 
 class CodeSigningEnvironmentRootAttributes(TopAttributes, metaclass=IterableMeta):
-	__config_class__ = "Code Signing Environment Root"
+    __config_class__ = "{key}"
