@@ -3,4 +3,4 @@ from pytpp.attributes.top import TopAttributes
 
 
 class CodeSigningFlowContainerAttributes(TopAttributes, metaclass=IterableMeta):
-	__config_class__ = "Code Signing Flow Container"
+    __config_class__ = "{key}"
