@@ -3,4 +3,4 @@ from pytpp.attributes.top import TopAttributes
 
 
 class CodeSigningFlowRootAttributes(TopAttributes, metaclass=IterableMeta):
-	__config_class__ = "Code Signing Flow Root"
+    __config_class__ = "{key}"
