@@ -3,4 +3,4 @@ from pytpp.attributes.top import TopAttributes
 
 
 class CodeSigningProjectContainerAttributes(TopAttributes, metaclass=IterableMeta):
-	__config_class__ = "Code Signing Project Container"
+    __config_class__ = "{key}"
