@@ -3,7 +3,7 @@ from pytpp.attributes.certificate_authority_base import CertificateAuthorityBase
 
 
 class ComodoCCMAttributes(CertificateAuthorityBaseAttributes, metaclass=IterableMeta):
-	__config_class__ = "Comodo CCM"
-	customer_login_uri = Attribute('Customer Login URI')
-	organization = Attribute('Organization')
-	secret_key = Attribute('Secret Key')
+    __config_class__ = "{key}"
+    customer_login_uri = Attribute('Customer Login URI')
+    organization = Attribute('Organization')
+    secret_key = Attribute('Secret Key')
