@@ -3,5 +3,5 @@ from pytpp.attributes.driver_base import DriverBaseAttributes
 
 
 class EncryptionDriverAttributes(DriverBaseAttributes, metaclass=IterableMeta):
-	__config_class__ = "Encryption Driver"
-	encryption_data = Attribute('Encryption Data')
+    __config_class__ = "{key}"
+    encryption_data = Attribute('Encryption Data')
