@@ -3,5 +3,5 @@ from pytpp.attributes.flow_action_base import FlowActionBaseAttributes
 
 
 class FlowActionApproverBaseAttributes(FlowActionBaseAttributes, metaclass=IterableMeta):
-	__config_class__ = "Flow Action Approver Base"
-	minimum_approvers = Attribute('Minimum Approvers', min_version='19.2')
+    __config_class__ = "{key}"
+    minimum_approvers = Attribute('Minimum Approvers', min_version='19.2')
