@@ -3,4 +3,4 @@ from pytpp.attributes.branch_base import BranchBaseAttributes
 
 
 class FlowRootAttributes(BranchBaseAttributes, metaclass=IterableMeta):
-	__config_class__ = "Flow Root"
+    __config_class__ = "{key}"
