@@ -3,8 +3,8 @@ from pytpp.attributes.http_ca_base import HTTPCABaseAttributes
 
 
 class GlobalSignMSSLCAAttributes(HTTPCABaseAttributes, metaclass=IterableMeta):
-	__config_class__ = "GlobalSign MSSL CA"
-	domain_id = Attribute('Domain ID')
-	profile_id = Attribute('Profile ID')
-	san_type = Attribute('SAN Type')
-	web_service_url = Attribute('Web Service URL')
+    __config_class__ = "{key}"
+    domain_id = Attribute('Domain ID')
+    profile_id = Attribute('Profile ID')
+    san_type = Attribute('SAN Type')
+    web_service_url = Attribute('Web Service URL')
