@@ -3,6 +3,6 @@ from pytpp.attributes.organization import OrganizationAttributes
 
 
 class IdentityRootAttributes(OrganizationAttributes, metaclass=IterableMeta):
-	__config_class__ = "Identity Root"
-	authentication_scheme = Attribute('Authentication Scheme')
-	identity_cache_timeout = Attribute('Identity Cache Timeout', min_version='16.2')
+    __config_class__ = "{key}"
+    authentication_scheme = Attribute('Authentication Scheme')
+    identity_cache_timeout = Attribute('Identity Cache Timeout', min_version='16.2')
