@@ -4,8 +4,8 @@ from pytpp.attributes.top import TopAttributes
 
 
 class JumpServerAttributes(ConnectionBaseAttributes, TopAttributes, metaclass=IterableMeta):
-	__config_class__ = "Jump Server"
-	consumers = Attribute('Consumers')
-	location = Attribute('Location')
-	ssh_connection_string = Attribute('SSH Connection String')
-	ssh_version = Attribute('SSH Version')
+    __config_class__ = "{key}"
+    consumers = Attribute('Consumers')
+    location = Attribute('Location')
+    ssh_connection_string = Attribute('SSH Connection String')
+    ssh_version = Attribute('SSH Version')
