@@ -3,4 +3,4 @@ from pytpp.attributes.service_module import ServiceModuleAttributes
 
 
 class KeyManagerAttributes(ServiceModuleAttributes, metaclass=IterableMeta):
-	__config_class__ = "Key Manager"
+    __config_class__ = "{key}"
