@@ -3,4 +3,4 @@ from pytpp.attributes.driver_base import DriverBaseAttributes
 
 
 class LayoutDriverBaseAttributes(DriverBaseAttributes, metaclass=IterableMeta):
-	__config_class__ = "Layout Driver Base"
+    __config_class__ = "{key}"
