@@ -3,4 +3,4 @@ from pytpp.attributes.organization import OrganizationAttributes
 
 
 class LayoutDriverContainerAttributes(OrganizationAttributes, metaclass=IterableMeta):
-	__config_class__ = "Layout Driver Container"
+    __config_class__ = "{key}"
