@@ -3,4 +3,4 @@ from pytpp.attributes.top import TopAttributes
 
 
 class LogApplicationContainerAttributes(TopAttributes, metaclass=IterableMeta):
-	__config_class__ = "Log Application Container"
+    __config_class__ = "{key}"
