@@ -3,6 +3,6 @@ from pytpp.attributes.top import TopAttributes
 
 
 class LogApplicationCustomizationAttributes(TopAttributes, metaclass=IterableMeta):
-	__config_class__ = "Log Application Customization"
-	customization_data = Attribute('Customization Data')
-	language = Attribute('Language')
+    __config_class__ = "{key}"
+    customization_data = Attribute('Customization Data')
+    language = Attribute('Language')
