@@ -3,7 +3,7 @@ from pytpp.attributes.top import TopAttributes
 
 
 class LogHeartbeatAttributes(TopAttributes, metaclass=IterableMeta):
-	__config_class__ = "Log Heartbeat"
-	event = Attribute('Event')
-	rule = Attribute('Rule')
-	timeout = Attribute('Timeout')
+    __config_class__ = "{key}"
+    event = Attribute('Event')
+    rule = Attribute('Rule')
+    timeout = Attribute('Timeout')
