@@ -3,6 +3,6 @@ from pytpp.attributes.top import TopAttributes
 
 
 class LogNotificationAttributes(TopAttributes, metaclass=IterableMeta):
-	__config_class__ = "Log Notification"
-	log_channel = Attribute('Log Channel')
-	rule = Attribute('Rule')
+    __config_class__ = "{key}"
+    log_channel = Attribute('Log Channel')
+    rule = Attribute('Rule')
