@@ -3,5 +3,5 @@ from pytpp.attributes.branch_base import BranchBaseAttributes
 
 
 class LogRootAttributes(BranchBaseAttributes, metaclass=IterableMeta):
-	__config_class__ = "Log Root"
-	log_application_container = Attribute('Log Application Container')
+    __config_class__ = "{key}"
+    log_application_container = Attribute('Log Application Container')
