@@ -3,5 +3,5 @@ from pytpp.attributes.metadata_base import MetadataBaseAttributes
 
 
 class MetadataListAttributes(MetadataBaseAttributes, metaclass=IterableMeta):
-	__config_class__ = "Metadata List"
-	single = Attribute('Single')
+    __config_class__ = "{key}"
+    single = Attribute('Single')
