@@ -3,4 +3,4 @@ from pytpp.attributes.credential_base import CredentialBaseAttributes
 
 
 class PasswordCredentialAttributes(CredentialBaseAttributes, metaclass=IterableMeta):
-	__config_class__ = "Password Credential"
+    __config_class__ = "{key}"
