@@ -3,5 +3,5 @@ from pytpp.attributes.certificate_trust_store_base import CertificateTrustStoreB
 
 
 class PEMTrustStoreAttributes(CertificateTrustStoreBaseAttributes, metaclass=IterableMeta):
-	__config_class__ = "PEM Trust Store"
-	key_store = Attribute('Key Store')
+    __config_class__ = "{key}"
+    key_store = Attribute('Key Store')
