@@ -3,4 +3,4 @@ from pytpp.attributes.top import TopAttributes
 
 
 class RemoteAccessApplicationContainerAttributes(TopAttributes, metaclass=IterableMeta):
-	__config_class__ = "Remote Access Application Container"
+    __config_class__ = "{key}"
