@@ -4,4 +4,4 @@ from pytpp.attributes.report_filter_base import ReportFilterBaseAttributes
 
 
 class ReportCertificateTrendsReportAttributes(ReportBaseAttributes, ReportFilterBaseAttributes, metaclass=IterableMeta):
-	__config_class__ = "Report:Certificate Trends Report"
+    __config_class__ = "{key}"
