@@ -4,6 +4,6 @@ from pytpp.attributes.report_filter_base import ReportFilterBaseAttributes
 
 
 class ReportCertificateDuplicationAttributes(ReportBaseAttributes, ReportFilterBaseAttributes, metaclass=IterableMeta):
-	__config_class__ = "Report:CertificateDuplication"
-	options = Attribute('Options', min_version='19.3')
-	policydn = Attribute('PolicyDN', min_version='19.3')
+    __config_class__ = "{key}"
+    options = Attribute('Options', min_version='19.3')
+    policydn = Attribute('PolicyDN', min_version='19.3')
