@@ -3,7 +3,7 @@ from pytpp.attributes.report_base import ReportBaseAttributes
 
 
 class ReportEnhancedCertificateExpirationAttributes(ReportBaseAttributes, metaclass=IterableMeta):
-	__config_class__ = "Report:EnhancedCertificateExpiration"
-	debug_file = Attribute('Debug File')
-	grouping = Attribute('Grouping')
-	options = Attribute('Options')
+    __config_class__ = "{key}"
+    debug_file = Attribute('Debug File')
+    grouping = Attribute('Grouping')
+    options = Attribute('Options')
