@@ -4,5 +4,5 @@ from pytpp.attributes.report_filter_base import ReportFilterBaseAttributes
 
 
 class ReportSSHAuthorizedUserAttributes(ReportBaseAttributes, ReportFilterBaseAttributes, metaclass=IterableMeta):
-	__config_class__ = "Report:SSH Authorized User"
-	options = Attribute('Options')
+    __config_class__ = "{key}"
+    options = Attribute('Options')
