@@ -4,9 +4,9 @@ from pytpp.attributes.report_filter_base import ReportFilterBaseAttributes
 
 
 class ReportTrustAttributes(ReportBaseAttributes, ReportFilterBaseAttributes, metaclass=IterableMeta):
-	__config_class__ = "Report:Trust"
-	discoverydn = Attribute('DiscoveryDN')
-	grouping = Attribute('Grouping')
-	options = Attribute('Options')
-	trustedca = Attribute('TrustedCA')
-	untrustedca = Attribute('UntrustedCA')
+    __config_class__ = "{key}"
+    discoverydn = Attribute('DiscoveryDN')
+    grouping = Attribute('Grouping')
+    options = Attribute('Options')
+    trustedca = Attribute('TrustedCA')
+    untrustedca = Attribute('UntrustedCA')
