@@ -3,7 +3,7 @@ from pytpp.attributes.certificate_authority_base import CertificateAuthorityBase
 
 
 class SelfSignedCAAttributes(CertificateAuthorityBaseAttributes, metaclass=IterableMeta):
-	__config_class__ = "Self Signed CA"
-	algorithm = Attribute('Algorithm')
-	enhanced_key_usage = Attribute('Enhanced Key Usage')
-	key_usage = Attribute('Key Usage')
+    __config_class__ = "{key}"
+    algorithm = Attribute('Algorithm')
+    enhanced_key_usage = Attribute('Enhanced Key Usage')
+    key_usage = Attribute('Key Usage')
