@@ -3,4 +3,4 @@ from pytpp.attributes.top import TopAttributes
 
 
 class SSHCATemplateContainerAttributes(TopAttributes, metaclass=IterableMeta):
-	__config_class__ = "SSH CA Template Container"
+    __config_class__ = "{key}"
