@@ -3,4 +3,4 @@ from pytpp.attributes.top import TopAttributes
 
 
 class SSHCertificateIssuanceFlowContainerAttributes(TopAttributes, metaclass=IterableMeta):
-	__config_class__ = "SSH Certificate Issuance Flow Container"
+    __config_class__ = "{key}"
