@@ -3,4 +3,4 @@ from pytpp.attributes.service_module import ServiceModuleAttributes
 
 
 class SSHCertificateManagerAttributes(ServiceModuleAttributes, metaclass=IterableMeta):
-	__config_class__ = "SSH Certificate Manager"
+    __config_class__ = "{key}"
