@@ -3,4 +3,4 @@ from pytpp.attributes.flow_action_base import FlowActionBaseAttributes
 
 
 class SSHCertificateStartProcessingActionAttributes(FlowActionBaseAttributes, metaclass=IterableMeta):
-	__config_class__ = "SSH Certificate Start Processing Action"
+    __config_class__ = "{key}"
