@@ -3,4 +3,4 @@ from pytpp.attributes.ssh_key import SSHKeyAttributes
 
 
 class SSHUserKeyAttributes(SSHKeyAttributes, metaclass=IterableMeta):
-	__config_class__ = "SSH User Key"
+    __config_class__ = "{key}"
