@@ -3,4 +3,4 @@ from pytpp.attributes.branch_base import BranchBaseAttributes
 
 
 class SSOAttributes(BranchBaseAttributes, metaclass=IterableMeta):
-	__config_class__ = "SSO"
+    __config_class__ = "{key}"
