@@ -3,6 +3,6 @@ from pytpp.attributes.person import PersonAttributes
 
 
 class UserAttributes(PersonAttributes, metaclass=IterableMeta):
-	__config_class__ = "User"
-	creation_date = Attribute('Creation Date')
-	password = Attribute('Password')
+    __config_class__ = "{key}"
+    creation_date = Attribute('Creation Date')
+    password = Attribute('Password')
