@@ -3,6 +3,6 @@ from pytpp.attributes.top import TopAttributes
 
 
 class UserPreferenceAttributes(TopAttributes, metaclass=IterableMeta):
-	__config_class__ = "User Preference"
-	console_timeout = Attribute('Console Timeout')
-	user_preferences = Attribute('User Preferences')
+    __config_class__ = "{key}"
+    console_timeout = Attribute('Console Timeout')
+    user_preferences = Attribute('User Preferences')
