@@ -3,4 +3,4 @@ from pytpp.attributes.x509_certificate import X509CertificateAttributes
 
 
 class X509DeviceCertificateAttributes(X509CertificateAttributes, metaclass=IterableMeta):
-	__config_class__ = "X509 Device Certificate"
+    __config_class__ = "{key}"
