@@ -3,8 +3,8 @@ from pytpp.attributes.certificate_authority_base import CertificateAuthorityBase
 
 
 class XolphinCAAttributes(CertificateAuthorityBaseAttributes, metaclass=IterableMeta):
-	__config_class__ = "Xolphin CA"
-	brand = Attribute('Brand')
-	included_domains = Attribute('Included Domains')
-	product = Attribute('Product')
-	type = Attribute('Type')
+    __config_class__ = "{key}"
+    brand = Attribute('Brand')
+    included_domains = Attribute('Included Domains')
+    product = Attribute('Product')
+    type = Attribute('Type')
